@@ -5,8 +5,10 @@ import json
 import logging
 import traceback
 
+import tornado.web
+
 from lesscode.db.redis.redis_helper import RedisHelper
-from tornado.options import options, define
+from tornado.options import options
 
 # 装饰器
 from lesscode.utils.JsonUtil import JSONEncoder
@@ -47,7 +49,7 @@ def deal_cache(func, ex, cache_key, *args, **params):
 
 
 def query_cache(cache_key, conn_name=options.cache_conn):
-    if options.cache_module:
+    if options.cache_enable:
         data = RedisHelper(conn_name).sync_get(cache_key)
         if data:
             value = json.loads(data)
@@ -59,7 +61,11 @@ def query_cache(cache_key, conn_name=options.cache_conn):
 
 
 def format_insert_key(func_name, args, params):
-    str_insert_key = str(args)
+    _args = []
+    for x in args:
+        if not issubclass(type(x), tornado.web.RequestHandler):
+            _args.append(x)
+    str_insert_key = str(_args)
     for k in params:
         if isinstance(params[k], dict):
             a = json.dumps(params[k])
@@ -74,7 +80,7 @@ def format_insert_key(func_name, args, params):
 
 
 def insert_cache(data, ex, cache_key, conn_name=options.cache_conn):
-    if options.cache_module:
+    if options.cache_enable:
         try:
             RedisHelper(conn_name).sync_set(cache_key, JSONEncoder().encode(data), ex=ex)
         except:
